<?php
// $Id:

define ('CFORGE_PROFILE_PATH', 'profiles/cforge/');

/**
 * Return an array of the modules to be enabled when this profile is installed.
 *
 * @return
 *   An array of modules to enable.
 */
function cforge_profile_modules() {
  //what happens if these mods aren't available?
  $core = array('contact', 'comment', 'dblog', 'help', 'menu', 'path', 'php', 'profile', 'search', 'taxonomy', 'token', 'update', 'upload');
  $common = array('captcha', 'content', 'date_api', 'image', 'imageapi', 'imageapi_gd', 'imagecache', 'jquery_ui', 'usertabs', 'views');
  $other = array('backup_migrate', 'date', 'date_popup', 'hierarchical_select', 'hs_taxonomy', 'image_gallery', 'jquerymenu', 'mcapi', 'simplenews', 'simplenews_action');
  return array_merge($core, $common, $other);
}

/**
 * Return a description of the profile for the initial installation screen.
 *
 * @return
 *   An array with keys 'name' and 'description' describing this profile,
 *   and optional 'language' to override the language selection for
 *   language-specific profiles.
 */
function cforge_profile_details() {
  return array(
    'name' => 'Community Forge',
    'description' => st('Full community accounting site similar to demo.communityforge.net')
  );
}

/**
 * Return a list of tasks that this profile supports.
 *
 * @return
 *   A keyed array of tasks the profile will perform during
 *   the final stage. The keys of the array will be used internally,
 *   while the values will be displayed to the user in the installer
 *   task list.
 */
function cforge_profile_task_list() {
  return array(
    'cforge_install' => st('Cforge options'),
  );
}


/**
 * Implementation of hook_form_alter().
 *
 * Allows the profile to alter the site-configuration form. This is
 * called through custom invocation, so $form_state is not populated.
 */
function cforge_form_alter(&$form, $form_state, $form_id) {
  if ($form_id != 'install_configure') return;

  if (is_file(CFORGE_PROFILE_PATH . 'matslats.inc')) {
    include_once(CFORGE_PROFILE_PATH . 'matslats.inc');
    $form['site_information']['site_name']['#default_value'] = $_SERVER['SERVER_NAME'];
    $form['admin_account']['account']['name']['#default_value'] = 'admin';
    $form['admin_account']['account']['name']['#type'] = 'hidden';
    $form['admin_account']['account']['pass']['#value'] = $cfpass;
    $form['admin_account']['account']['pass']['#type'] = 'hidden';
    $form['admin_account']['account']['mail']['#default_value'] = 'tim@communityforge.net';
    $form['admin_account']['account']['mail']['#type'] = 'hidden';
    $form['server_settings']['date_default_timezone']['#default_value'] = 3600;
  }
}

/**
 * implements install hook_tasks
 * see default.profile for more details
 */
function cforge_profile_tasks(&$task, $url) {
  $modules = array('community_tasks', 'calendar', 'cforge_docs', 'imagecache_profiles', 'jcalendar', 'mc_display', 'mc_multiple', 'mc_webforms', 'mc_signatures', 'offers_wants', 'role_expire', 'views_bonus_export', 'content_copy', 'mc_webform_1stparty', 'mc_user_limits', 'intertrading', 'taxonomy_xml');
  drupal_install_modules($modules);

  //some defaults...before language variables installed
  variable_set('date_format_short', "d-m-y");
  variable_set('date_format_medium', "H:i, D jS M");
  variable_set('date_format_long', "H:i, l jS F, Y");

  $types = array(
    array(
      'type' => 'page',
      'name' => st('Page'),
      'module' => 'node',
      'description' => st("If you wish to add a menu item, please create a page. This is useful for adding pages such as 'our charter' that you'd like to display to visitors, or members."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
    array(
      'type' => 'story',
      'name' => st('Article'),
      'module' => 'node',
      'description' => st("Create and post articles that inform your members and animate your association. By default, the info appears on the 'Info' page and provides members can add comments."),
      'custom' => TRUE,
      'modified' => TRUE,
      'locked' => FALSE,
    ),
  );
  foreach ($types as $type) {
    $type = (object) _node_type_set_defaults($type);
    node_type_save($type);
  }
  db_query("UPDATE {node_type} SET name = '%s' where type = '%s'", array(':name'=> st('Newsletter'), ':type' => 'simplenews'));

  //create roles
  db_query("INSERT INTO {role} (rid, name)
      VALUES (%d, 'trader'), (%d, 'committee'), (%d, 'accountant'), (%d, 'local admin'), (%d, 'system');",
    array(RID_TRADER, RID_COMMITTEE, RID_ACCOUNTANT, RID_LOCAL_ADMIN, RID_SYSTEM)
  );

  //create profile fields
  $fields = array(
    1 => array('profile_firstname', st('First name'), '', st('Details'), 'textfield', -20, 1, 1, 2, 0),
    2 => array('profile_familyname', st('Family name'), '', st('Details'), 'textfield', -19, 1, 1, 2, 0),
    3 => array('profile_responsibility', st('Responsibility'), st('Job title, for committee members only'), st('Details'), 'textfield', -15, 0, 0, 2, 0),
    4 => array('profile_phone1', st('Phone Number 1'), '', st('Details'), 'textfield', 0, 0, 1, 1, 0),
    5 => array('profile_phone2', st('Phone Number 2'), '', st('Details'), 'textfield', 0, 0, 1, 1, 0),
    6 => array('profile_locality', st('Area Code'), st('This may be the zip code, or some other way to group the members geographically'), st('Details'), 'textfield', 11, 0, 1, 2, 0),
    7 => array('profile_postal', st('Postal member'), st('Please post printed directories to me '), st('Details'), 'checkbox', 21, 0, 1, 2, 0),
    8 => array('profile_address', st('Address'), st('This is necessary if you want to receive printed updates'), st('Details'), 'textarea', 10, 0, 1, 2, 0),
    9 => array('profile_notes', st('Notes'), st('This is for any additional notes.'), st('Details'), 'textarea', 50, 0, 1, 2, 0),
  );
  foreach ($fields as $fid => $values) {
    db_query("REPLACE into {profile_fields}
      (fid, name, title, explanation, category, type, weight, required, register, visibility, autocomplete)
      VALUES ($fid, '%s', '%s', '%s', '%s', '%s', %d, %d, %d, %d, %d)",
      $values
    );
  }

  //Allow committee to use html filter
  db_query("UPDATE {filter_formats} SET roles = ',%d,' WHERE name = 'Full HTML'", array(RID_COMMITTEE));

  //set theme
  variable_set('theme_default', 'sky_seldulac');
  variable_set('theme_settings', array(
    'toggle_logo' => TRUE,
    'toggle_name' => TRUE,
    'toggle_slogan' => 1,
    'toggle_mission' => 0,
    'toggle_node_user_picture' => 0,
    "toggle_comment_user_picture" => 0,
    "toggle_search" => 1,
    "toggle_favicon" => 1,
    "toggle_primary_links" => 1,
    "toggle_secondary_links" => 1,
    "toggle_node_info_event" => 1,
    "toggle_node_info_faq" => 0,
    "toggle_node_info_image" => 1,
    "toggle_node_info_story" => 0,
    "toggle_node_info_page" => 0,
    "toggle_node_info_exchange" => 1,
    "toggle_node_info_proposition" => 1,
    "toggle_node_info_document" => 1,
    "default_favicon"=> 1,
    "default_logo"=> 1,
  ));
  variable_set('theme_sky_seldulac_settings', array(
    'sky_seldulac_breadcrumbs' => 0,
    'sky_seldulac_breadcrumbs_sep' => '&raquo;',
    'sky_seldulac_font' => 'lucida',
    'sky_seldulac_font_headings' => 'lucida',
    'sky_seldulac_font_size' => '12px',
    'sky_seldulac_header_height' => 'auto',
    'sky_seldulac_layout' => 'fluid_98',
    'sky_seldulac_title' => 1,
    'sky_seldulac_nav_alignment' => 'center',
    'sky_seldulac_sub_navigation_size' => '15em',
    'sky_seldulac_wireframe' => '0',
    'sky_seldulac_themer_classes' => 0
  ));

  variable_set('image_attach_simplenews', FALSE);
  variable_set('image_attach_size_body_simplenews', 'preview');
  variable_set('image_attach_size_teaser_simplenews', 'thumbnail');
  variable_set('image_attach_story', TRUE);
  variable_set('image_attach_size_body_story', 'preview');
  variable_set('image_attach_size_teaser_story', 'thumbnail');
  variable_set('image_attach_page', TRUE);
  variable_set('image_attach_size_body_page', 'preview');
  variable_set('image_attach_size_teaser_page', 'thumbnail');
  $image_sizes = array(
    '_original' => array(
      'label' => 'Original',
      'operation' => 'scale',
      'width' => '',
      'height' => '',
      'link' => 1,
    ),
    'thumbnail' => array(
      'label' => 'Vignette',
      'operation' => 'scale',
      'width' => 150,
      'height' => 150,
      'link' => 1,
    ),
    'preview' => array(
      'label' => 'Preview',
      'operation' => 'scale',
      'width' => 640,
      'height' => 640,
      'link' => 1,
    )
  );
  variable_set('image_sizes', $image_sizes);
  db_query(
    "UPDATE {node_type} SET title_label = '%s' WHERE type = 'image'",
    array(':label' => st("An image which appears in a 'gallery'. When you upload an image you choose on the form which gallery it belongs to. Create new galleries via the manage menu."))
  );


 //image gallery
  if ($vid = variable_get('image_gallery_nav_vocabulary', 0)) {
    $term = array(
      'vid' => variable_get('image_gallery_nav_vocabulary', 0),
      'name' => st('LETS life'),
      'weight' => 3,
    );
    taxonomy_save_term($term);
  }
  else {
    watchdog('install_profile', 'no image vocabulary identifed, and default gallery not installed');
  }

  //imagecache presets
  variable_set('user_picture_imagecache_comments', 'user_image_default');
  variable_set('user_picture_imagecache_profiles', 'user_image_default');
  variable_set('user_picture_imagecache_profiles_default', 'user_image_default');
  variable_set('user_picture_imagecache_profiles_min_height', '150');
  variable_set('user_picture_imagecache_profiles_min_width', '150');
  variable_set('preprocess_css', TRUE);
  variable_set('preprocess_js', TRUE);

  //node settings
  variable_set('node_options_page', array('status'));


  //system settings
  variable_set('site_offline_message', st("Community Forge has taken your site offline briefly for maintenance. Thank you for your patience."));
  variable_set('site_slogan', st("Your slogan here"));
  variable_set('anonymous', st("Visitor"));
  variable_set('user_register', "2");
  variable_set('user_pictures', "1");
  variable_set('user_picture_dimensions', '1280x1024');
  variable_set('user_picture_file_size', '1024');
  variable_set('user_picture_default', 'profiles/cforge/anonymous.jpg');

  //upload settings
  variable_set('upload_uploadsize_default', 5);
  variable_set('upload_usersize_default', 25);
  variable_set('upload_event', 1);
  variable_set('upload_community_task', 1);
  variable_set('upload_documents', 1);
  variable_set('upload_members_only', 1);
  variable_set('upload_page', 1);
  variable_set('upload_simplenews', FALSE);
  variable_set('date_default_timezone', 7200);
  variable_set('date_default_timezone_name', "Europe/Zurich");

  //comment settings
  variable_set('comment_image', 2);
  variable_set('comment_page', 2);
  variable_set('comment_story', 2);
  //other settings
  variable_set('cforge_report', 1);
  variable_set('cf_unlaunched', TRUE);
  variable_set('user_mail_password_reset_subject', st('New password for !site'));

  //for when the administrator creates an account
  variable_set('user_mail_register_admin_created_subject', "Your new account at !site");
  variable_set('user_mail_register_admin_created_body', st("!username,

A site administrator at !site has created an account for you. You may now log in to !login_uri using the following username and password:

Username : !username
password: !password

You may also log in by clicking on this link or copying and pasting it in your browser:

!login_url

This is a one-time login, so it can be used only once.

After logging in, you will be redirected to !edit_uri so you can change your password.

--  !site team"));

  //for when the user creates an account
  variable_set('user_mail_pending_approval_subject', "Account details for !username at !site (pending admin approval)");
  variable_set('user_mail_pending_approval_body', "!username,

Thank you for registering at !site. Your application for an account is currently pending approval. Once it has been approved, you will receive another e-mail containing information about how to log in, set your password, and other details.

--  !site team");

  //for when an account is unblocked.
  variable_set('user_mail_status_activated_subject', "Account details for !username at !site (approved)");
  variable_set('user_mail_status_activated_body', "!username,

Your account at !site has been activated.

You may now log in by clicking on this link or copying and pasting it in your browser:

!login_url

This is a one-time login, so it can be used only once.

After logging in, you will be redirected to !edit_uri so you can change your password.

Once you have set your own password, you will be able to log in to !login_uri in the future using:

Username : !username");

  //import the l contentType, with it's datetime field,
  //from an included file, which is a dump generated by content_copy module
  include_once './'. drupal_get_path('module', 'node') .'/content_types.inc';
  include_once('./'. drupal_get_path('module', 'content') .'/includes/content.admin.inc');
  $form_state['values']['type_name'] ='<create>';
  $form_state['values']['macro'] = file_get_contents(CFORGE_PROFILE_PATH . 'datefield.cck');
  drupal_execute("content_copy_import_form", $form_state);
  content_clear_type_cache();

  if (is_file(CFORGE_PROFILE_PATH . 'matslats.inc')) {
    include_once(CFORGE_PROFILE_PATH . 'matslats.inc');
  }

  //mcapi settings
  variable_set('mc_subtypes', array(INCOMING_SIGNED => st('I am asking'), OUTGOING_SIGNED => st('I am giving')));
  variable_set('mc_notification_default', 1);
  variable_set('mc_notification_throttle_default', 2);
  variable_set('mc_sig_notification_default', 1);
  variable_set('mc_sig_notification_option', 1);
  variable_set('mc_notification_subject', st("Exchange created on !site by !username"));
  variable_set('mc_notification_body', st("Hello !username\n\n A new exchange was recorded."));
  variable_set('mc_notification_update_body', st("Hello !username,\n\nAn exchange involving you was modified:\n!summary"));
  variable_set('mc_notification_update_subject', st("Exchange modified on !site"));
  variable_set('mc_signatures_notification_subject', st("New exchange to confirm on !site"));
  variable_set('mc_signatures_notification_body', st("Click on the link to confirm the exchange: !sign_link"));
  variable_set('mc_notification_option', FALSE);
  variable_set('mc_signatures_signoff_subject', st('Notification from !site'));
  variable_set('mc_signatures_signoff_body', 'Greetings

The following exchange was confirmed and your balance updated:
!summary

The team at !site');
  variable_set('mc_stats_exclude', '1');
  variable_set('mc_tabs_css', 'tab-wrapper');
  variable_set('mc_live_stats', TRUE);

  //offers_wants settings
  variable_set('offers_wants_expiry', TRUE);
  variable_set('proposition_has_body', TRUE);
  variable_set('offers_wants_proposition_wants', TRUE);
  variable_set('comment_proposition', TRUE);

  //community task settings
  db_query(
    "UPDATE {node_type} SET description = '%s' WHERE type = 'community_task'",
    array(':desc' => st('Allows you to: enter a to-do task; list the tasks for members to commit to them; remind the committed member on his list of contributions; assign a recognition point when the task is accomplished.'))
  );


  //backup_restore settings
  $nodata = array ('cache', 'cache_block', 'cache_content', 'cache_filter',  'cache_form', 'cache_hierarchical_select',
    'cache_menu', 'cache_page', 'cache_update', 'cache_views', 'cache_views_data', 'captcha_points', 'captcha_sessions',
    'flood',  'search_dataset', 'search_index', 'search_node_links', 'search_total', 'semaphore', 'sessions',
    'views_object_cache', 'watchdog'
  );
  $filters = array(
    'compression' => 'zip',
    'notify_success_enable' => 0,
    'notify_success_email' => 'admin@matslats.net',
    'notify_failure_enable' => 0,
    'notify_failure_email' => 'admin@matslats.net',
    'utils_site_offline' => 0,
    'utils_site_offline_message' => st('Community Forge has taken your site offline briefly for maintenance. Thank you for your patience.'),
    'exclude_tables' => array (),
    'nodata_tables' => drupal_map_assoc($nodata),
    'utils_lock_tables' => 1
  );
  db_query("UPDATE backup_migrate_profiles SET
      name = 'Cforge_backup', filename = 'cforge', append_timestamp = 1, timestamp_format = 'Y-m-d\\TH-i-s', filters = '%s'
      WHERE profile_id = 'default'", serialize($filters)
  );

  //hiearchical_select settings
  variable_set('taxonomy_hierarchical_select_1', TRUE);
  variable_get('hs_config_taxonomy-1', array(
    'config_id' => 'taxonomy-1',
    'save_lineage' => 1,
    'enforce_deepest' => 0,
    'entity_count' => 0,
    'require_entity' => 0,
    'resizable' => 1,
    'level_labels' => array(
      'status' => 1,
      'labels' => array(
        '0' => 'Concerne',
      )
    ),
    'dropbox' => array(
        'status' => 1,
        'title' => 'All selections',
        'limit' => 0,
        'reset_hs' => 1
      ),
    'editability' => array(
      'status' => 0,
      'item_types' => array(
        '0' => NULL
      ),
      'allowed_levels' => array(
        '0' => 1
      ),
      'allow_new_levels' => 0,
        'max_levels' => 1
      )
    )
  );

  //simplenews settings
  $term = array(
    'vid' => variable_get('simplenews_vid', 0),
    'name' => st('Governance'),
    'weight' => 0,
    'description' => st('A newsletter for the decision makers')
  );
  taxonomy_save_term($term);

  variable_set('cforge_install_unconfigured', TRUE);
  $task = 'profile-finished';//this means we passed validation
  variable_set('site_frontpage', "admin/build/modules");
  drupal_set_message(t('Now install !module', array('!module' => l('cforge_custom', 'admin/build/modules'))), 'warning');
}
